@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: latexmacros.ml,v 1.56 2006/05/12 16:05:02 filliatr Exp $ i*)
+(*i $Id: latexmacros.ml,v 1.59 2006-11-02 11:58:41 filliatr Exp $ i*)
 
 (*s This code is Copyright (C) 1997  Xavier Leroy. *)
 
@@ -94,6 +94,10 @@ def "\\mathnormal" [Print "<i>" ; Print_arg ; Print "</i>"];
 def "\\mathcal" [Print_arg];
 def "\\mathbb" [Print_arg];
 
+def "\\textin" [Print "<sub>"; Print_arg; Print "</sub>"];
+def "\\textsu" [Print "<sup>"; Print_arg; Print "</sup>"];
+def "\\textsi" [Print "<i>" ; Print_arg ; Print "</i>"];
+
 (* Basic color support. *)
 
 def "\\textcolor" [ Parameterized (function name ->
@@ -115,6 +119,11 @@ def "\\textsf" [Print "<b>" ; Print_arg ; Print "</b>"];
 def "\\mathsf" [Print "<b>" ; Print_arg ; Print "</b>"];
 def "\\textsc" [Print_arg];
 
+def "\\textln" [Print_arg];
+def "\\textos" [Print_arg];
+def "\\textdf" [Print_arg];
+def "\\textsw" [Print_arg];
+
 def "\\rm" [];
 def "\\cal" [];
 def "\\emph" [Print "<em>" ; Print_arg ; Print "</em>"];
@@ -229,6 +238,12 @@ def "\\v" [Raw_arg(function "r" -> print_s "&#X0159;"
                           | "i" -> print_s "&#X012D;"
                           | "I" -> print_s "&#X012C;"
 			  | s   -> print_s s)];
+def "\\H" [Raw_arg (function 
+		      | "O" -> print_s "&#336;"
+		      | "o" -> print_s "&#337;"
+		      | "U" -> print_s "&#368;"
+		      | "u" -> print_s "&#369;"
+		      | s -> print_s s)];
 
 (* Math macros *)
 def "\\[" [Print "<blockquote>"];
@@ -391,8 +406,15 @@ def "\\Omega" [Print "&Omega;"];
 def "\\bysame" [Print "<u>&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;</u>"];
 def "\\MR" 
   [Raw_arg (fun s -> 
+	      let mr = 
+		try 
+		  let i = String.index s ' ' in
+		  if i=0 then raise Not_found;
+		  String.sub s 0 i
+		with Not_found -> s
+	      in
 	      print_s "<a href=\"http://www.ams.org/mathscinet-getitem?mr=";
-	      print_s s; print_s "\">MR "; print_s s; print_s "</a>")];
+	      print_s mr; print_s "\">MR "; print_s s; print_s "</a>")];
 def "\\MRhref" 
   [Print "<a href=\"http://www.ams.org/mathscinet-getitem?mr=";
    Print_arg; Print "\">"; Print_arg; Print "</a>"];
