@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: main.ml,v 1.59 2006/05/12 16:05:02 filliatr Exp $ i*)
+(*i $Id: main.ml,v 1.64 2006-11-02 11:58:41 filliatr Exp $ i*)
 
 (*s Main module of bibtex2html. *)
 
@@ -138,7 +138,12 @@ let call_bibtex tmp =
   end;
   match 
     let redir = 
-      if !output_file = "" || !Options.quiet then "> /dev/null 2>&1" else "" 
+      if !output_file = "" || !Options.quiet then 
+	match Sys.os_type with 
+	  | "Win32" -> "> nul 2>&1"
+	  | _ -> "> /dev/null 2>&1" 
+      else 
+	"" 
     in
     Sys.command (sprintf "%s %s %s" !command tmp redir)
   with
@@ -256,7 +261,7 @@ let translate fullname =
     if fullname = "" then begin
       let tmp = Filename.temp_file "bibtex2htmlinput" ".bib" in
       let ch = open_out tmp in
-      Biboutput.output_bib false ch input_bib None;
+      Biboutput.output_bib ~html:false ch input_bib None;
       close_out ch;
       let bbl = get_biblios tmp in
       Sys.remove tmp;
@@ -326,12 +331,18 @@ Usage: bibtex2html <options> [filename]
   -nodoc     only produces the body of the HTML documents
   -nokeys    do not print the BibTeX keys
   -nolinks   do not print any web link
+  -nobiblinks
+             do not add web links in the BibTeX output
   -rawurl    print URL instead of file type
   -heveaurl  use HeVeA's \\url macro
   -noabstract
              do not print the abstracts (if any)
   -nokeywords
              do not print the keywords (if any)
+  -nodoi     do not insert the DOI links
+  -doi-prefix url
+             set the DOI links prefix (default is http://dx.doi.org/)
+  -linebreak add a linebreak between an entry and its links
   -noheader  do not print the header (bibtex2html command)
   -nofooter  do not print the footer (bibtex2html web link)
   -noexpand  do not expand abbreviations in the BibTeX output
@@ -388,12 +399,22 @@ let parse () =
 	usage()
     | ("-noabstract" | "-no-abstract" | "--no-abstract") :: rem ->
 	print_abstract := false; parse_rec rem
+    | ("-nodoi" | "-no-doi" | "--no-doi") :: rem ->
+	doi := false; parse_rec rem
+    | ("-doi-prefix" | "--doi-prefix") :: s :: rem ->
+	doi_prefix := s; parse_rec rem
+    | ("-doi-prefix" | "--doi-prefix") :: [] ->
+	usage ()
     | ("-nokeywords" | "-no-keywords" | "--no-keywords") :: rem ->
 	print_keywords := false; parse_rec rem
     | ("-nolinks" | "-no-links" | "--no-links") :: rem -> 
 	print_links := false; parse_rec rem
+    | ("-nobiblinks" | "-no-bib-links" | "--no-bib-links") :: rem -> 
+	links_in_bib_file := false; parse_rec rem
     | ("-nokeys" | "-no-keys" | "--no-keys") :: rem -> 
 	nokeys := true; table := NoTable; parse_rec rem
+    | ("-use-table" | "--use-table") :: rem -> 
+	table := Table; parse_rec rem
     | ("-usekeys" | "-use-keys" | "--use-keys") :: rem ->
 	use_keys := true; parse_rec rem
     | ("-rawurl" | "-raw-url" | "--raw-url") :: rem -> 
@@ -404,6 +425,8 @@ let parse () =
 i*)
     | ("-heveaurl" | "-hevea-url" | "--hevea-url") :: rem -> 
 	Latexscan.hevea_url := true; parse_rec rem
+    | ("-linebreak" | "--linebreak") :: rem ->
+	linebreak := true; parse_rec rem
     | ("-noheader" | "-no-header" | "--no-header") :: rem ->
 	print_header := false; parse_rec rem
     | ("-nofooter" | "-no-footer" | "--no-footer") :: rem ->
