@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: translate.ml,v 1.72 2006/05/15 09:45:53 filliatr Exp $ i*)
+(*i $Id: translate.ml,v 1.76 2006-11-02 11:58:41 filliatr Exp $ i*)
 
 (*s Production of the HTML documents from the BibTeX bibliographies. *)
 
@@ -39,14 +39,18 @@ let single = ref false
 let both = ref false
 let user_footer = ref ""
 let bib_entries = ref true
+let links_in_bib_file = ref true
 let input_file = ref ""
 let output_file = ref ""
 let bibentries_file = ref ""
 let title_url = ref false
 let use_label_name = ref false
 let use_keys = ref false
+let linebreak = ref false
 let note_fields = ref ([] : string list)
 let abstract_name = ref "Abstract"
+let doi = ref true
+let doi_prefix = ref "http://dx.doi.org/"
 
 type table_kind = Table | DL | NoTable
 let table = ref Table
@@ -197,8 +201,7 @@ let get_url s =
   else
     s
 
-let link_name (u, name) url s =
-  match name with
+let link_name (u, name) url s = match name with
   | Some name ->
       name
   | None ->
@@ -299,6 +302,15 @@ let display_keywords ch e =
   with Not_found -> 
     ()
 
+let doi_link e =
+  if !doi then begin
+    try
+      let k = Expand.get_uppercase_field e "DOI" in
+      [{ l_url = !doi_prefix ^ k; l_name = "DOI" }]
+    with Not_found -> []
+  end else
+    []
+
 (* Printing of one entry *)  
 
 let bibtex_entry k =
@@ -311,9 +323,11 @@ let separate_file (b,((_,k,f) as e)) =
   in_summary := false;
   let file = k ^ !file_suffix in
   let ch = open_out file in
-  let title = sprintf "%s : %s" !output_file k in
-  if not !nodoc then
-    Html.open_document ch (fun () -> output_string ch title);
+  if not !nodoc then begin
+    let f = if !title_spec then !title else !output_file in
+    let title = sprintf "%s : %s" f k in
+    Html.open_document ch (fun () -> output_string ch title)
+  end;
   if !print_header then header ch;
   Html.open_balise ch "h2";
   latex2html ch b;
@@ -327,7 +341,7 @@ let separate_file (b,((_,k,f) as e)) =
   Html.paragraph ch;
   display_notes ch e;
   if !print_keywords then display_keywords ch e;
-  display_links ch (labs @ bibtex_entry k :: make_links e);
+  display_links ch (labs @ bibtex_entry k :: doi_link e @ make_links e);
   (* JK Html.paragraph ch; *)
   Html.open_href ch (!output_file ^ !link_suffix);
   output_string ch "Back";
@@ -397,7 +411,7 @@ let one_entry_summary ch biblio (_,b,((_,k,f) as e)) =
   output_string ch "\n"; 
   new_column ch;
   latex2html ch b;
-  (*Html.open_balise ch "br /";*)
+  if !linebreak then Html.open_balise ch "br /";
   output_string ch "\n";
 
   if !multiple then
@@ -405,9 +419,9 @@ let one_entry_summary ch biblio (_,b,((_,k,f) as e)) =
   else if !single then begin
     let ks = Bibtex.KeySet.singleton k in
     let ks = Bibfilter.saturate biblio ks in
-    Biboutput.output_bib true ch biblio (Some ks);
+    Biboutput.output_bib ~html:true ch biblio (Some ks);
   end else begin
-    let links = make_links e in
+    let links = doi_link e @ make_links e in
     let links = if !bib_entries then bibtex_entry k :: links else links in
     match make_abstract e with
       | Atext a -> 
@@ -480,14 +494,23 @@ let bib_file bl keys =
   end;
   let ch = open_out fn in
 
-  if not !nodoc then
-    Html.open_document ch (fun _ -> output_string ch !input_file);
-
+  if not !nodoc then begin
+    let t = if !title_spec then !title else !input_file in
+    Html.open_document ch (fun _ -> output_string ch t)
+  end;
+    
   Html.open_balise ch "h1";
   output_string ch !input_file;
   Html.close_balise ch "h1";
 
-  Biboutput.output_bib true ch bl keys;
+  let output_bib =
+    if !links_in_bib_file then
+      let html_file = !output_file ^ !link_suffix in
+      Biboutput.output_bib ~html:true ~html_file ch
+    else
+      Biboutput.output_bib ~html:true ch
+  in
+  output_bib bl keys;
   
   if !print_footer then footer ch;
   if not !nodoc then Html.close_document ch;
