@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: translate.mli,v 1.9 2006/05/12 16:05:02 filliatr Exp $ i*)
+(*i $Id: translate.mli,v 1.12 2006-11-02 11:58:41 filliatr Exp $ i*)
 
 (*s Production of the HTML documents from the BibTeX bibliographies. *)
 
@@ -43,6 +43,10 @@ val bib_entries : bool ref
 val input_file : string ref
 val output_file : string ref
 val use_label_name : bool ref
+val linebreak : bool ref
+val doi : bool ref
+val doi_prefix : string ref
+val links_in_bib_file : bool ref
 
 type table_kind = Table | DL | NoTable
 val table : table_kind ref
